# Stetl Examples

The directories below each show various examples for Stetl.
Best is to first browse [The Basic Examples](basics)

For more examples and cases see the following projects:

* [NLExtract](https://github.com/nlextract/NLExtract) - conversion of Open Dutch geodata sets
* [Smart Emission](https://github.com/Geonovum/smartemission/tree/master/etl) - IoT SensorWeb/SOS
